@@ -12,10 +12,11 @@ from psycopg2._psycopg import connection
 from pyproj import CRS
 from shapely.geometry.base import BaseGeometry, BaseMultipartGeometry, GEOMETRY_TYPES
 from sshtunnel import SSHTunnelForwarder
+from typepigeon import guard_generic_alias
 
 from tablecrow.tables.base import DatabaseTable, parse_record_values, random_open_tcp_port
 
-from ..utilities import guard_generic_alias, parse_hostname, split_hostname_port
+from ..utilities import parse_hostname, split_hostname_port
 
 SSH_DEFAULT_PORT = 22
 
@@ -255,6 +256,8 @@ class PostGresTable(DatabaseTable):
 
         schema = []
         for field, field_type in self.fields.items():
+            field_type = guard_generic_alias(field_type)
+
             if field_type in [list, tuple, Sequence, Collection]:
                 field_type = [typing_get_args(field_type[0])]
             dimensions = 0
@@ -268,7 +271,7 @@ class PostGresTable(DatabaseTable):
                 field_type = dict
 
             try:
-                field_type = self.FIELD_TYPES[guard_generic_alias(field_type.__name__)]
+                field_type = self.FIELD_TYPES[field_type.__name__]
             except KeyError:
                 raise TypeError(f'PostGres does not support type "{field_type}"')
 
